@@ -137,22 +137,22 @@ struct _ThunarLocationButtons
 {
   GtkContainer __parent__;
 
-  GtkWidget         *left_slider;
-  GtkWidget         *right_slider;
-  GtkWidget         *filler_widget;
+  GtkWidget           *left_slider;
+  GtkWidget           *right_slider;
+  GtkWidget           *filler_widget;
 
-  ThunarFile        *current_directory;
+  ThunarFile          *current_directory;
 
-  gint               slider_width;
-  gboolean           ignore_click : 1;
+  gint                 slider_width;
+  gboolean             ignore_click : 1;
 
-  ThunarLauncher    *launcher;
-  GList             *list;
-  GList             *fake_root_button;
-  GList             *first_visible_button;
-  GList             *last_visible_button;
+  ThunarActionManager *action_mgr;
+  GList               *list;
+  GList               *fake_root_button;
+  GList               *first_visible_button;
+  GList               *last_visible_button;
 
-  guint              scroll_timeout_id;
+  guint                scroll_timeout_id;
 };
 
 
@@ -279,6 +279,13 @@ thunar_location_buttons_init (ThunarLocationButtons *buttons)
                                "path-bar");
 
   /* add sub-buttons to css class which matches all buttons in the path-bar */
+  /* keep as well the old name 'path-bar-button'. It might be used by themes */
+  gtk_style_context_add_class (gtk_widget_get_style_context (GTK_WIDGET (buttons->left_slider)),
+                               "location-button");
+  gtk_style_context_add_class (gtk_widget_get_style_context (GTK_WIDGET (buttons->right_slider)),
+                               "location-button");
+  gtk_style_context_add_class (gtk_widget_get_style_context (GTK_WIDGET (buttons->filler_widget)),
+                               "location-button");
   gtk_style_context_add_class (gtk_widget_get_style_context (GTK_WIDGET (buttons->left_slider)),
                                "path-bar-button");
   gtk_style_context_add_class (gtk_widget_get_style_context (GTK_WIDGET (buttons->right_slider)),
@@ -286,9 +293,9 @@ thunar_location_buttons_init (ThunarLocationButtons *buttons)
   gtk_style_context_add_class (gtk_widget_get_style_context (GTK_WIDGET (buttons->filler_widget)),
                                "path-bar-button");
 
-  buttons->launcher =  g_object_new (THUNAR_TYPE_LAUNCHER, "widget", GTK_WIDGET (buttons), NULL);
-  g_signal_connect_swapped (G_OBJECT (buttons->launcher), "change-directory", G_CALLBACK (thunar_location_buttons_set_current_directory), buttons);
-  g_signal_connect_swapped (G_OBJECT (buttons->launcher), "open-new-tab", G_CALLBACK (thunar_navigator_open_new_tab), buttons);
+  buttons->action_mgr =  g_object_new (THUNAR_TYPE_ACTION_MANAGER, "widget", GTK_WIDGET (buttons), NULL);
+  g_signal_connect_swapped (G_OBJECT (buttons->action_mgr), "change-directory", G_CALLBACK (thunar_location_buttons_set_current_directory), buttons);
+  g_signal_connect_swapped (G_OBJECT (buttons->action_mgr), "open-new-tab", G_CALLBACK (thunar_navigator_open_new_tab), buttons);
 }
 
 
@@ -1202,12 +1209,12 @@ thunar_location_buttons_context_menu (ThunarLocationButton  *button,
     return FALSE;
 
   files = g_list_append (NULL, file);
-  g_object_set (G_OBJECT (buttons->launcher), "current-directory", file, NULL);
-  g_object_set (G_OBJECT (buttons->launcher), "selected-files", files, NULL);
+  g_object_set (G_OBJECT (buttons->action_mgr), "current-directory", file, NULL);
+  g_object_set (G_OBJECT (buttons->action_mgr), "selected-files", files, NULL);
   g_list_free (files);
   is_current_directory = g_file_equal (thunar_file_get_file (file), thunar_file_get_file (buttons->current_directory));
   context_menu = g_object_new (THUNAR_TYPE_MENU, "menu-type", THUNAR_MENU_TYPE_CONTEXT_LOCATION_BUTTONS,
-                                                 "launcher", buttons->launcher,
+                                                 "action_mgr", buttons->action_mgr,
                                                  "force-section-open", TRUE,
                                                  "change_directory-support-disabled", is_current_directory, NULL);
   if (is_current_directory)
@@ -1225,7 +1232,7 @@ thunar_location_buttons_context_menu (ThunarLocationButton  *button,
     }
   else
     {
-      /* context menu on some other pathbar element */
+      /* context menu on some other location button */
       thunar_menu_add_sections (context_menu, THUNAR_MENU_SECTION_OPEN
                                             | THUNAR_MENU_SECTION_SENDTO
                                             | THUNAR_MENU_SECTION_COPY_PASTE
@@ -1235,7 +1242,7 @@ thunar_location_buttons_context_menu (ThunarLocationButton  *button,
                                             | THUNAR_MENU_SECTION_CUSTOM_ACTIONS
                                             | THUNAR_MENU_SECTION_PROPERTIES);
     }
-  thunar_menu_hide_accel_labels (context_menu);
+  thunar_gtk_menu_hide_accel_labels (GTK_MENU (context_menu));
   gtk_widget_show_all (GTK_WIDGET (context_menu));
   window = gtk_widget_get_toplevel (GTK_WIDGET (buttons));
   thunar_window_redirect_menu_tooltips_to_statusbar (THUNAR_WINDOW (window), GTK_MENU (context_menu));
